@@ -1,75 +1,74 @@
 """To use this module just use the main function at the top of your code."""
-from types import ModuleType
-from sys import modules
+
+from sys import modules as __modules
 import importlib
-ProtectFiles, ProtectDirs, LockPerms, Silent = range(4)
-__protectfiles, __silent = None, None
+_ProtectFiles, _ProtectDirs, _LockPerms, _Silent = range(4)
+__version__, __file__, __protectfiles, __silent, __oldopen = "1.3.0", None, None, None, open
 __restrict = {
-    "os": ["system", "popen", "kill", "spawn", "execl", "execle", "execlp", "execlpe", "execv", "execve", "execvp", "execvpe", "killpg", "fork", "forkpty", "plock"],
-    "subprocess": ["run", "check_output", "call","Popen"],
+    "os": ["system", "popen", "kill", "spawn", "execl", "execle", "execlp", "execlpe", "execv", "execve", "execvp", "execvpe", "killpg", "fork", "forkpty", "plock", "popen2", "popen3"],
+    "subprocess": ["run", "check_output", "call", "Popen", "check_call", "getstatusoutput", "getoutput"],
     "pathlib.Path": [],
     "shutil": []
 }
-def main(*args) -> None:
+def ref(*args) -> None:
     """
     # Usage
 
     ## Basic usage
 
     ```py
-    import ref
-    ref.main()
+    __ref__() # no need to import anything
     ```
 
     ## Additional options
 
-    - ProtectFiles
+    - _ProtectFiles
 
-    The `ProtectFiles` option allows you to prevent Python files from using `open` to overwrite files, and block functions like `os.remove` from deleting files.
+    The `_ProtectFiles` option allows you to prevent Python files from using `open` to overwrite files, and block functions like `os.remove` from deleting files.
 
     To use, replace the setup with:
 
     ```py
-    ref.main(ref.ProtectFiles)
+    __ref__(ref._ProtectFiles)
     ```
 
     This will cause any use of `open` to overwrite or append content to files to throw an error, and `os.remove`,`os.unlink`, and a few others are deleted.
 
-    - ProtectDirs
+    - _ProtectDirs
 
-    The `ProtectDirs` option protects against the deletion of directories.
+    The `_ProtectDirs` option protects against the deletion of directories.
 
     To use, replace the setup with:
 
     ```py
-    ref.main(ref.ProtectDirs)
+    __ref__(ref._ProtectDirs)
     ```
 
-    - LockPerms
+    - _LockPerms
 
     This will prevent use of chmod in that Python file.
 
     To use, replace the setup with:
 
     ```py
-    ref.main(ref.LockPerms)
+    __ref__(ref._LockPerms)
     ```
 
-    - Silent
+    - _Silent
 
     This will replace any removed function with a dummy function.
 
     To use, replace the setup with:
 
     ```py
-    ref.main(ref.Silent)
+    __ref__(ref._Silent)
     ```
 
     That way, you won't get an error when trying to use `os.system("echo \"doing something that harms your system...\"")` but nothing will happen
 
     """
     global __protectfiles, __restrict, __silent
-    protectfiles, protectdirs, lockperms, silent = [i in args for i in range(4)]
+    protectfiles, protectdirs, lockperms, silent = map(lambda x: x in args, range(4))
     __protectfiles, __silent = protectfiles, silent
     if protectfiles:
         __restrict["os"].extend(["remove", "unlink", "rename", "replace"])
@@ -82,11 +81,11 @@ def main(*args) -> None:
     if lockperms:
         __restrict["os"].append("chmod")
         __restrict["pathlib.Path"].append("chmod")
-    modules['__main__'].__builtins__.__dict__['__import__'] = __import
-    modules['__main__'].__builtins__.__dict__['open'] = __open
+    __modules['__main__'].__builtins__.__dict__['__import__'] = __import
+    __modules['__main__'].__builtins__.__dict__['open'] = __open
 def __open(filename, mode="r", *args, **kwargs):
     if __protectfiles and ("w" in mode or "a" in mode): raise AttributeError()
-    return open(filename, mode, *args, **kwargs)
+    return __oldopen(filename, mode, *args, **kwargs)
 def __import(name, *args):
     try: M = importlib.__import__(name, *args)
     except AttributeError: return __import__
@@ -98,3 +97,4 @@ def __import(name, *args):
                     else: del M.__dict__[method]
                 except (AttributeError, KeyError): pass
     return M
+if __name__ != '__main__': __modules['__main__'].__builtins__.__dict__['__ref__'] = ref
